"""Helper function to return only the major landmarks from a large list."""
from ..structs.landmark import Landmark

def take_most_important(
    landmarks: list[Landmark],
    n_important: int
) -> list[Landmark]:
    """
    Given a list of landmarks, return the most important landmarks based on their attractiveness.
    
    Args:
        landmarks (list[Landmark]): List of landmarks that needs to be truncated
        n_important (int): Number of most important landmarks to return
    
    Returns:
        list[Landmark]: List of the n_important most important landmarks
    """
    if n_important == 0 :
        raise ValueError('Number of landmarks to keep cannot be zero.')

    # Sort landmarks by attractiveness (descending)
    sorted_landmarks = sorted(landmarks, key=lambda x: x.attractiveness, reverse=True)

    return sorted_landmarks[:n_important]
